@@ -1,2 +1,2 @@
-from . import config_context, dsl_parser
+from . import project_config_context, dsl_parser
 from . import db_adapter_generator, domain_generator, rest_generator
