@@ -3,7 +3,7 @@ Implements `ICommonGenerator` protocol interface
 """
 from pathlib import Path
 
-from ..config_context import get_config
+from ..project_config_context import get_project_config
 from ...utils.file_utils import get_java_filename
 
 from crudhex.domain.ports import domain_code_writer
@@ -22,7 +22,7 @@ def create_class(folder: Path) -> Path:
 
 
 def get_package() -> str:
-    return get_config().domain_exceptions_pkg
+    return get_project_config().domain_exceptions_pkg
 
 
 def get_type_name() -> str:
