@@ -28,18 +28,33 @@ def create_shared_class(generator: Union['ISharedGenerator', Any], entities_map:
     return True, generator.create_class(entities_map, *args, folder)
 
 
+def create_common_class(generator: Union['ICommonGenerator', Any], *args,
+                        override: bool = False, folder: Optional[Path] = None, default_folder: Path) -> Tuple[bool, Path]:
+
+    folder = create_first_folder(folder, default_folder)
+    file = folder / generator.get_filename()
+    if not override and file.exists():
+        return False, file
+
+    return True, generator.create_class(*args, folder)
+
+
 class IGenerator(Protocol):
 
-    def create_class(self, entity: Entity, *args) -> Path:
+    @staticmethod
+    def create_class(entity: Entity, *args) -> Path:
         ...
 
+    @staticmethod
     def get_package(self) -> str:
         ...
 
-    def get_type_name(self, entity: Entity) -> str:
+    @staticmethod
+    def get_type_name(entity: Entity) -> str:
         ...
 
-    def get_filename(self, entity: Entity) -> str:
+    @staticmethod
+    def get_filename(entity: Entity) -> str:
         ...
 
 
@@ -60,3 +75,21 @@ class ISharedGenerator(Protocol):
     @staticmethod
     def get_filename() -> str:
         ...
+
+
+class ICommonGenerator(Protocol):
+    @staticmethod
+    def create_class(*args) -> Path:
+        ...
+
+    @staticmethod
+    def get_package() -> str:
+        ...
+
+    @staticmethod
+    def get_type_name() -> str:
+        ...
+
+    @staticmethod
+    def get_filename() -> str:
+        ...
\ No newline at end of file
